@@ -466,6 +466,14 @@ void parser(void)
             dostru(arg);
             goto wayout;
 #ifndef MINIMAL
+        } else if (!strcmp(cmd, "connect") ||
+                   !strcmp(cmd, "delete") ||
+                   !strcmp(cmd, "get") ||
+                   !strcmp(cmd, "head") ||
+                   !strcmp(cmd, "options") ||
+                   !strcmp(cmd, "post") ||
+                   !strcmp(cmd, "put")) {
+            die(500, LOG_INFO, "HTTP command: [%s]", cmd);
         } else if (!strcmp(cmd, "help")) {
             goto help_site;
 #endif
@@ -635,7 +643,7 @@ void parser(void)
                     modern_listings = 0;
                     donlist(arg, 1, 1, 1, 1);
                 } else {
-                    addreply_noformat(211, "http://www.pureftpd.org/");
+                    addreply_noformat(211, "https://www.pureftpd.org/");
                 }
 #endif
             } else if (!strcmp(cmd, "list")) {
@@ -692,14 +700,6 @@ void parser(void)
             } else if (!strcmp(cmd, "abor")) {
                 addreply_noformat(226, MSG_ABOR_SUCCESS);
 #ifndef MINIMAL
-            } else if (!strcmp(cmd, "connect") ||
-                       !strcmp(cmd, "delete") ||
-                       !strcmp(cmd, "get") ||
-                       !strcmp(cmd, "head") ||
-                       !strcmp(cmd, "options") ||
-                       !strcmp(cmd, "post") ||
-                       !strcmp(cmd, "put")) {
-                die(500, LOG_INFO, "HTTP command: [%s]", cmd);
             } else if (!strcmp(cmd, "site")) {
                 if ((sitearg = arg) != NULL) {
                     while (*sitearg != 0 && !isspace((unsigned char) *sitearg)) {
