@@ -415,9 +415,24 @@ extern int opt_a, opt_C, opt_d, opt_F, opt_l, opt_R;
 #endif
 
 #ifdef WITH_TLS
-# ifndef TLS_CERTIFICATE_FILE
-#  define TLS_CERTIFICATE_FILE "/etc/ssl/private/pure-ftpd.pem"
+# ifndef TLS_CONFDIR
+#  define TLS_CONFDIR "/etc/ssl/private"
 # endif
+# ifndef TLS_CERTIFICATE_FILE
+#  define TLS_CERTIFICATE_FILE TLS_CONFDIR "/pure-ftpd.pem"
+# endif
+# ifndef TLS_DHPARAMS_FILE
+#  define TLS_DHPARAMS_FILE TLS_CONFDIR "/pure-ftpd-dhparams.pem"
+# endif
+#endif
+
+#ifndef TLS_DEFAULT_CIPHER_SUITE
+# define TLS_DEFAULT_CIPHER_SUITE \
+    "ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA:ECDHE-RSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-RSA-AES256-SHA256:DHE-RSA-AES256-SHA:ECDHE-ECDSA-DES-CBC3-SHA:ECDHE-RSA-DES-CBC3-SHA:EDH-RSA-DES-CBC3-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:DES-CBC3-SHA:!DSS"
+#endif
+
+#ifndef TLS_DEFAULT_ECDH_CURVE
+# define TLS_DEFAULT_ECDH_CURVE "prime256v1"
 #endif
 
 #define FAKE_SHELL "ftp"
@@ -539,7 +554,7 @@ Your platform has a very large PATH_MAX, we should not trust it.
 
 #ifndef MAX_DATA_SIZE
 # ifdef HAVE_LIBSODIUM
-#  define MAX_DATA_SIZE (24 * 1024 * 1024)
+#  define MAX_DATA_SIZE (40 * 1024 * 1024)
 # elif defined(WITH_LDAP) || defined(WITH_MYSQL) || defined(WITH_PGSQL)
 #  define MAX_DATA_SIZE (16 * 1024 * 1024)       /* Max memory usage - SQL/LDAP need more */
 # else
