@@ -564,6 +564,16 @@ void pw_ldap_check(AuthResult * const result,
         result->backend_data = NULL;
         spwd = pw->pw_passwd;
 #ifdef HAVE_LIBSODIUM
+# ifdef crypto_pwhash_STRPREFIX
+        if (strncasecmp(spwd, PASSWD_LDAP_ARGON2I_PREFIX,
+                        sizeof PASSWD_LDAP_ARGON2I_PREFIX - 1U) == 0) {
+            spwd += (sizeof PASSWD_LDAP_ARGON2I_PREFIX - 1U);
+            if (crypto_pwhash_str_verify(spwd, password, strlen(password)) == 0) {
+                goto pwd_ok;
+            }
+            return;
+        } else
+# endif
         if (strncasecmp(spwd, PASSWD_LDAP_SCRYPT_PREFIX,
                         sizeof PASSWD_LDAP_SCRYPT_PREFIX - 1U) == 0) {
             spwd += (sizeof PASSWD_LDAP_SCRYPT_PREFIX - 1U);
