@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "No se han podido alternar capacidades"
 #define MSG_CLIENT_CLOSED_CNX "El cliente cerr la conexin"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Los siguientes alias estn disponibles :"
 #define MSG_PERUSER_MAX "No puedo aceptar ms de %lu conexiones del mismo usuario"
 #define MSG_IPV6_OK "Las conexiones IPv6 tambin son bienvenidas en este servidor"
-#define MSG_TLS_INFO "SSL/TLS: Activado %s con %s, %d bits de cifrado"
-#define MSG_TLS_WEAK "SSL/TLS: Cifrado demasiado dbil"
+#define MSG_TLS_INFO "TLS: Activado %s con %s, %d bits de cifrado"
+#define MSG_TLS_WEAK "TLS: Cifrado demasiado dbil"
 #define MSG_TLS_NEEDED "Lo siento. No se aceptan sesiones sin cifrar en este servidor.\n" \
-    "Por favor, vuelva a conectar utilizando mecanismos de seguridad SSL/TLS."
+    "Por favor, vuelva a conectar utilizando mecanismos de seguridad TLS."
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
